==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/ListAuditMitigationActionsTasksResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListAuditMitigationActionsTasksResponse(
    tasks: Optional[
      Iterable[zio.aws.iot.model.AuditMitigationActionsTaskMetadata]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse = {
    import ListAuditMitigationActionsTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
      .builder()
      .optionallyWith(
        tasks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tasks)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iot.model.ListAuditMitigationActionsTasksResponse.ReadOnly =
    zio.aws.iot.model.ListAuditMitigationActionsTasksResponse
      .wrap(buildAwsValue())
}
object ListAuditMitigationActionsTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListAuditMitigationActionsTasksResponse =
      zio.aws.iot.model.ListAuditMitigationActionsTasksResponse(
        tasks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tasks: Optional[
      List[zio.aws.iot.model.AuditMitigationActionsTaskMetadata.ReadOnly]
    ]
    def nextToken: Optional[NextToken]
    def getTasks: ZIO[Any, AwsError, List[
      zio.aws.iot.model.AuditMitigationActionsTaskMetadata.ReadOnly
    ]] = AwsError.unwrapOptionField("tasks", tasks)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
  ) extends zio.aws.iot.model.ListAuditMitigationActionsTasksResponse.ReadOnly {
    override val tasks: Optional[
      List[zio.aws.iot.model.AuditMitigationActionsTaskMetadata.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.tasks())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iot.model.AuditMitigationActionsTaskMetadata.wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
  ): zio.aws.iot.model.ListAuditMitigationActionsTasksResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.104.11-sources.jar: zio/aws/iot/model/ListAuditMitigationActionsTasksResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListAuditMitigationActionsTasksResponse(
    tasks: Option[
      Iterable[zio.aws.iot.model.AuditMitigationActionsTaskMetadata]
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse = {
    import ListAuditMitigationActionsTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
      .builder()
      .optionallyWith(
        tasks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tasks)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iot.model.ListAuditMitigationActionsTasksResponse.ReadOnly =
    zio.aws.iot.model.ListAuditMitigationActionsTasksResponse
      .wrap(buildAwsValue())
}
object ListAuditMitigationActionsTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListAuditMitigationActionsTasksResponse =
      zio.aws.iot.model.ListAuditMitigationActionsTasksResponse(
        tasks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tasks: Option[
      List[zio.aws.iot.model.AuditMitigationActionsTaskMetadata.ReadOnly]
    ]
    def nextToken: Option[NextToken]
    def getTasks: ZIO[Any, AwsError, List[
      zio.aws.iot.model.AuditMitigationActionsTaskMetadata.ReadOnly
    ]] = AwsError.unwrapOptionField("tasks", tasks)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
  ) extends zio.aws.iot.model.ListAuditMitigationActionsTasksResponse.ReadOnly {
    override val tasks: Option[
      List[zio.aws.iot.model.AuditMitigationActionsTaskMetadata.ReadOnly]
    ] = scala
      .Option(impl.tasks())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iot.model.AuditMitigationActionsTaskMetadata.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListAuditMitigationActionsTasksResponse
  ): zio.aws.iot.model.ListAuditMitigationActionsTasksResponse.ReadOnly =
    new Wrapper(impl)
}
